If you are using this package, please consider to cite the follow two papers:
https://journals.aps.org/prb/abstract/10.1103/PhysRevB.110.L121404
https://pubs.aip.org/aip/jcp/article/161/16/164702/3317708